==> flutter_ads-0.0.1.tar.gz: android/src/main/java/com/nova/flutter_ads/FlutterAdsSplashView.java <==
package com.nova.flutter_ads;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;

import com.ark.adkit.basics.models.OnSplashImpl;
import com.ark.adkit.polymers.polymer.ADTool;

import io.flutter.app.FlutterActivity;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.StringCodec;
import io.flutter.plugin.platform.PlatformView;

public class FlutterAdsSplashView implements PlatformView {

    private final FrameLayout rootView;

    private final static String splashEventName = "plugins.nova.ads.event/splashview";

    private Handler handler;

    private static BasicMessageChannel<String> runTimeSender;

    FlutterAdsSplashView(FlutterActivity activity, Context context, BinaryMessenger messenger, int id) {
        rootView = new FrameLayout(context);
        FrameLayout.LayoutParams layoutParams =
                new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT);
        rootView.setLayoutParams(layoutParams);
        LinearLayout flAd = new LinearLayout(context);
        rootView.addView(flAd);
        this.handler = new Handler(Looper.getMainLooper());
        runTimeSender = new BasicMessageChannel<String>(messenger, splashEventName, StringCodec.INSTANCE);

        ADTool.getADTool().getManager()
                .getSplashWrapper().
                needPermissions(true)
                .loadSplash(activity, flAd, rootView, new OnSplashImpl() {
                    @Override
                    public void onAdTimeTick(long tick) {
                        handler.post(new Runnable() {
                            @Override
                            public void run() {
                                runTimeSender.send("123");
                            }
                        });
                    }

                    @Override
                    public void onAdShouldLaunch() {
                        handler.post(new Runnable() {
                            @Override
                            public void run() {
                                runTimeSender.send("finish");
                            }
                        });
                    }

                    @Override
                    public void onAdDisable() {
                        super.onAdDisable();
                        handler.post(new Runnable() {
                            @Override
                            public void run() {
                                runTimeSender.send("finish");
                            }
                        });
                    }
                });


    }

    @Override
    public View getView() {
        return rootView;
    }

    @Override
    public void dispose() {

    }
}

==> flutter_ads-0.1.3.tar.gz: android/src/main/java/com/nova/flutter_ads/FlutterAdsSplashView.java <==
package com.nova.flutter_ads;

import android.app.Activity;
import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;

import com.ark.adkit.basics.models.OnSplashImpl;
import com.ark.adkit.polymers.polymer.ADTool;

import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.StringCodec;
import io.flutter.plugin.platform.PlatformView;

public class FlutterAdsSplashView implements PlatformView {

    private final FrameLayout rootView;

    private final static String splashEventName = "plugins.nova.ads.event/splashview";

    private Handler handler;

    private static BasicMessageChannel<String> runTimeSender;

    FlutterAdsSplashView(Activity activity, Context context, BinaryMessenger messenger, int id) {
        rootView = new FrameLayout(context);
        FrameLayout.LayoutParams layoutParams =
                new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT);
        rootView.setLayoutParams(layoutParams);
        LinearLayout flAd = new LinearLayout(context);
        rootView.addView(flAd);
        this.handler = new Handler(Looper.getMainLooper());
        runTimeSender = new BasicMessageChannel<String>(messenger, splashEventName, StringCodec.INSTANCE);
        ADTool.getADTool().getManager()
                .getSplashWrapper().
                needPermissions(true)
                .loadSplash(activity, flAd, rootView, new OnSplashImpl() {
                    @Override
                    public void onAdTimeTick(long tick) {
                        handler.post(new Runnable() {
                            @Override
                            public void run() {
                                runTimeSender.send("123");
                            }
                        });
                    }

                    @Override
                    public void onAdShouldLaunch() {
                        handler.post(new Runnable() {
                            @Override
                            public void run() {
                                runTimeSender.send("finish");
                            }
                        });
                    }

                    @Override
                    public void onAdDisable() {
                        super.onAdDisable();
                        handler.post(new Runnable() {
                            @Override
                            public void run() {
                                runTimeSender.send("finish");
                            }
                        });
                    }
                });


    }

    @Override
    public View getView() {
        return rootView;
    }

    @Override
    public void dispose() {

    }
}
